@@ -14,7 +14,7 @@ use utf8;
 ## use critic (Modules::RequireExplicitPackage)
 
 package Sys::OsPackage;
-$Sys::OsPackage::VERSION = '0.1.1';
+$Sys::OsPackage::VERSION = '0.1.2';
 use Config;
 use Carp qw(carp croak confess);
 use Sys::OsRelease;
@@ -641,12 +641,16 @@ sub resolve_platform
 
     # collect uname info
     my $uname = $self->sysenv("uname");
-    if (not defined $uname) {
-        croak "error: can't find uname command to collect system information";
+    if (defined $uname) {
+        # Unix-like systems all have uname
+        $self->sysenv("os", $self->capture_cmd($uname, "-s"));
+        $self->sysenv("kernel", $self->capture_cmd($uname, "-r"));
+        $self->sysenv("machine", $self->capture_cmd($uname, "-m"));
+    } else {
+        # if the platform doesn't have uname (mainly Windows), get what we can from the Perl configuration
+        $self->sysenv("os", $Config{osname});
+        $self->sysenv("machine", $Config{archname});
     }
-    $self->sysenv("os", $self->capture_cmd($uname, "-s"));
-    $self->sysenv("kernel", $self->capture_cmd($uname, "-r"));
-    $self->sysenv("machine", $self->capture_cmd($uname, "-m"));
 
     # initialize Sys::OsRelease and set platform type
     my $osrelease = Sys::OsRelease->instance(common_id => sysconf("common_id"));
@@ -1044,7 +1048,7 @@ Sys::OsPackage - install OS packages and determine if CPAN modules are packaged
 
 =head1 VERSION
 
-version 0.1.1
+version 0.1.2
 
 =head1 SYNOPSIS
 
@@ -1074,10 +1078,6 @@ Ubuntu is supported by the Debian driver.
 
 Other packaging systems for Unix-like operating systems should be feasible to add by writing a driver module.
 
-=head1 NAME
-
-Sys::OsPackage - install OS packages and determine if CPAN modules are packaged for the OS
-
 =head1 SEE ALSO
 
 L<Sys::OsPackage::Driver>
